@@ -16,15 +16,16 @@ import Pyro4.constants
 
 
 class Configuration(object):
-    __slots__ = ("HOST", "NS_HOST", "NS_PORT", "NS_BCPORT", "NS_BCHOST",
+    __slots__ = ("HOST", "NS_HOST", "NS_PORT", "NS_BCPORT", "NS_BCHOST", "NS_AUTOCLEAN",
                  "COMPRESSION", "SERVERTYPE", "COMMTIMEOUT",
                  "POLLTIMEOUT", "THREADING2", "ONEWAY_THREADED",
                  "DETAILED_TRACEBACK", "SOCK_REUSE", "SOCK_NODELAY", "PREFER_IP_VERSION",
-                 "THREADPOOL_SIZE", "AUTOPROXY", "PICKLE_PROTOCOL_VERSION",
+                 "THREADPOOL_SIZE", "THREADPOOL_SIZE_MIN", "AUTOPROXY", "PICKLE_PROTOCOL_VERSION",
                  "BROADCAST_ADDRS", "NATHOST", "NATPORT", "MAX_MESSAGE_SIZE",
                  "FLAME_ENABLED", "SERIALIZER", "SERIALIZERS_ACCEPTED", "LOGWIRE",
                  "METADATA", "REQUIRE_EXPOSE", "USE_MSG_WAITALL", "JSON_MODULE",
-                 "MAX_RETRIES")
+                 "MAX_RETRIES", "DILL_PROTOCOL_VERSION", "ITER_STREAMING", "ITER_STREAM_LIFETIME",
+                 "ITER_STREAM_LINGER")
 
     def __init__(self):
         self.reset()
@@ -39,6 +40,7 @@ class Configuration(object):
         self.NS_PORT = 9090  # tcp
         self.NS_BCPORT = 9091  # udp
         self.NS_BCHOST = None
+        self.NS_AUTOCLEAN = 0.0
         self.NATHOST = None
         self.NATPORT = 0
         self.COMPRESSION = False
@@ -50,7 +52,8 @@ class Configuration(object):
         self.THREADING2 = False  # use threading2 if available?
         self.ONEWAY_THREADED = True  # oneway calls run in their own thread
         self.DETAILED_TRACEBACK = False
-        self.THREADPOOL_SIZE = 16
+        self.THREADPOOL_SIZE = 40
+        self.THREADPOOL_SIZE_MIN = 4
         self.AUTOPROXY = True
         self.MAX_MESSAGE_SIZE = 0  # 0 = unlimited
         self.BROADCAST_ADDRS = "<broadcast>, 0.0.0.0"  # comma separated list of broadcast addresses
@@ -60,11 +63,22 @@ class Configuration(object):
         self.SERIALIZERS_ACCEPTED = "serpent,marshal,json"   # these are the 'safe' serializers
         self.LOGWIRE = False  # log wire-level messages
         self.PICKLE_PROTOCOL_VERSION = pickle.HIGHEST_PROTOCOL
+        try:
+            import platform
+            if platform.python_implementation() in ('PyPy', 'IronPython'):
+                raise ImportError('Currently dill is not supported with PyPy and IronPython')
+            import dill
+            self.DILL_PROTOCOL_VERSION = dill.HIGHEST_PROTOCOL  # Highest protocol
+        except ImportError:
+            self.DILL_PROTOCOL_VERSION = -1
         self.METADATA = True  # get metadata from server on proxy connect
-        self.REQUIRE_EXPOSE = False  # require @expose to make members remotely accessible (if False, everything is accessible)
+        self.REQUIRE_EXPOSE = True  # require @expose to make members remotely accessible (if False, everything is accessible)
         self.USE_MSG_WAITALL = hasattr(socket, "MSG_WAITALL") and platform.system() != "Windows"      # not reliable on windows even though it is defined
         self.JSON_MODULE = "json"
         self.MAX_RETRIES = 0
+        self.ITER_STREAMING = True
+        self.ITER_STREAM_LIFETIME = 0.0
+        self.ITER_STREAM_LINGER = 30.0
 
         if useenvironment:
             # process environment variables
@@ -87,6 +101,7 @@ class Configuration(object):
                         else:
                             envvalue = valuetype(envvalue)  # just cast the value to the appropriate type
                     setattr(self, symbol, envvalue)
+
         self.SERIALIZERS_ACCEPTED = set(self.SERIALIZERS_ACCEPTED.split(','))
 
     def asDict(self):
